#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 microstache
version:              1.0.3.1
visibility:           public
id:                   microstache-1.0.3.1-3lTZD1RS7aNCM9eKcaxIPN
key:                  microstache-1.0.3.1-3lTZD1RS7aNCM9eKcaxIPN
license:              BSD-3-Clause
maintainer:           Oleg Grenrus<oleg.grenrus@iki.fi>
author:
    Mark Karpov <markkarpov@openmailbox.org>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/microstache
synopsis:             Mustache templates for Haskell
description:
    Mustache templates for Haskell.

    Based on @stache@ library, which uses @megaparsec@.
    This library uses @parsec@, thus the name: @microstache@.

category:             Text
abi:                  256f0c2f3ef52b6afaf6c8c5633cb188
exposed:              True
exposed-modules:
    Text.Microstache Text.Microstache.Compile Text.Microstache.Parser
    Text.Microstache.Render Text.Microstache.Type

import-dirs:          /usr/lib/ghc-9.6.6/site-local/microstache-1.0.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/microstache-1.0.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/microstache-1.0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-microstache
hs-libraries:         HSmicrostache-1.0.3.1-3lTZD1RS7aNCM9eKcaxIPN
depends:
    aeson-2.2.2.0-3pjCpj5XtaHAHmzSwnt06z base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    parsec-3.1.16.1 text-2.0.2 transformers-0.6.1.0
    vector-0.13.2.0-9mJIQr0XJi1KVzSJMcMTkU

haddock-interfaces:   /usr/share/doc/haskell-microstache/html/microstache.haddock
haddock-html:         /usr/share/doc/haskell-microstache/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

